/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ProjectComplianceFrameworkConfig extends cdktf.TerraformMetaArguments {
    /**
    * Globally unique ID of the compliance framework to assign to the project.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gitlabhq/gitlab/16.3.0/docs/resources/project_compliance_framework#compliance_framework_id ProjectComplianceFramework#compliance_framework_id}
    */
    readonly complianceFrameworkId: string;
    /**
    * The ID or full path of the project to change the compliance framework of.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gitlabhq/gitlab/16.3.0/docs/resources/project_compliance_framework#project ProjectComplianceFramework#project}
    */
    readonly project: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/gitlabhq/gitlab/16.3.0/docs/resources/project_compliance_framework gitlab_project_compliance_framework}
*/
export declare class ProjectComplianceFramework extends cdktf.TerraformResource {
    static readonly tfResourceType = "gitlab_project_compliance_framework";
    /**
    * Create a new {@link https://registry.terraform.io/providers/gitlabhq/gitlab/16.3.0/docs/resources/project_compliance_framework gitlab_project_compliance_framework} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ProjectComplianceFrameworkConfig
    */
    constructor(scope: Construct, id: string, config: ProjectComplianceFrameworkConfig);
    private _complianceFrameworkId?;
    get complianceFrameworkId(): string;
    set complianceFrameworkId(value: string);
    get complianceFrameworkIdInput(): string | undefined;
    get id(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    get projectInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
